==> argo-0.0.1.tar.gz: lib/src/widgets/responsive_visibility.dart <==
import 'package:flutter/widgets.dart';

import '../models/condition.dart';
import '../models/condition_breakpoint.dart';
import '../models/condition_screen.dart';
import '../models/screen_breakpoints.dart';
import '../utils/get_condition_breakpoint.dart';
import '../utils/get_condition_screen.dart';

/// Widget to handle the visbility with conditions [ConditionBreakpoint or ConditionScreen]
class ResponsiveVisibility extends StatelessWidget {
  final Widget child;
  final List<ConditionBreakpoint<bool>> hiddenWhen;
  final List<ConditionBreakpoint<bool>> visibleWhen;
  final ConditionScreen<bool> conditionScreen;
  final bool visible;
  final ScreenBreakpoints? localBreakpoints;
  final ConditionType? type;

  const ResponsiveVisibility.conditions({
    Key? key,
    required this.child,
    this.visible = true,
    this.visibleWhen = const [],
    this.hiddenWhen = const [],
    this.localBreakpoints,
  })  : type = ConditionType.conditions,
        conditionScreen = _defaultConditionScreenVisibility,
        super(key: key);

  const ResponsiveVisibility.screen({
    Key? key,
    required this.child,
    this.visible = true,
    this.conditionScreen = _defaultConditionScreenVisibility,
    this.localBreakpoints,
  })  : type = ConditionType.screen,
        visibleWhen = const [],
        hiddenWhen = const [],
        super(key: key);

  @override
  Widget build(BuildContext context) {
    // Initialize mutable value holders.
    final bool visibleValue = getVisibilityValue(context);

    return visibleValue ? child : const SizedBox();
  }

  bool getVisibilityValue(BuildContext context) {
    final List<ConditionBreakpoint<bool>> conditions = [];
    bool visibleValue = visible;

    // Combine Conditions.
    conditions.addAll(visibleWhen.map((e) => e.copyWith(value: true)));
    conditions.addAll(hiddenWhen.map((e) => e.copyWith(value: false)));

    if (type! == ConditionType.conditions) {
      visibleValue = valueFromConditionByBreakpoints<bool>(
        context: context,
        condition: conditions,
        localBreakpoints: localBreakpoints,
        defaultValue: visibleValue,
      );
    } else {
      visibleValue = valueFromConditionByScreen<bool>(
        context: context,
        condition: conditionScreen,
        localBreakpoints: localBreakpoints,
        defaultValue: visibleValue,
      );
    }

    return visibleValue;
  }
}

const _defaultConditionScreenVisibility = ConditionScreen<bool>(
  mobile: true,
  tablet: false,
  desktop: false,
);

==> argo-0.0.2.tar.gz: lib/src/widgets/responsive_visibility.dart <==
import 'package:flutter/widgets.dart';

import '../models/condition.dart';
import '../models/condition_breakpoint.dart';
import '../models/condition_screen.dart';
import '../models/screen_breakpoints.dart';
import '../utils/get_condition_breakpoint.dart';
import '../utils/get_condition_screen.dart';

/// {@template responsive_visibility}
///
/// Widget to show or hide a `child` depending of the [Condition].
/// You can use [ConditionScreen] or [ConditionBreakpoint] each one will bring you a different control
///
/// {@endtemplate}

class ResponsiveVisibility extends StatelessWidget {
  const ResponsiveVisibility.conditions({
    Key? key,
    required this.child,
    this.visible = true,
    this.visibleWhen = const [],
    this.hiddenWhen = const [],
    this.localBreakpoints,
  })  : type = ConditionType.conditions,
        conditionScreen = _defaultConditionScreenVisibility,
        super(key: key);

  const ResponsiveVisibility.screen({
    Key? key,
    required this.child,
    this.visible = true,
    this.conditionScreen = _defaultConditionScreenVisibility,
    this.localBreakpoints,
  })  : type = ConditionType.screen,
        visibleWhen = const [],
        hiddenWhen = const [],
        super(key: key);

  /// The widget to show or hide
  final Widget child;

  /// List of conditions to hide when they are met [ConditionBreakpoint]
  final List<ConditionBreakpoint<bool>> hiddenWhen;

  /// List of conditions to show when they are met [ConditionBreakpoint]
  final List<ConditionBreakpoint<bool>> visibleWhen;

  /// Do the manage of the visibility by [ConditionScreen]
  final ConditionScreen<bool> conditionScreen;

  /// the defoult value of the widget
  final bool visible;

  /// Are the local breakpoints for the widget
  final ScreenBreakpoints? localBreakpoints;

  /// The type of conditions that was invoked
  final ConditionType? type;

  @override
  Widget build(BuildContext context) {
    // Initialize mutable value holders.
    final bool visibleValue = getVisibilityValue(context);

    return visibleValue ? child : const SizedBox();
  }

  bool getVisibilityValue(BuildContext context) {
    final List<ConditionBreakpoint<bool>> conditions = [];
    bool visibleValue = visible;

    // Combine Conditions.
    conditions.addAll(visibleWhen.map((e) => e.copyWith(value: true)));
    conditions.addAll(hiddenWhen.map((e) => e.copyWith(value: false)));

    if (type! == ConditionType.conditions) {
      visibleValue = valueFromConditionByBreakpoints<bool>(
        context: context,
        condition: conditions,
        localBreakpoints: localBreakpoints,
        defaultValue: visibleValue,
      );
    } else {
      visibleValue = valueFromConditionByScreen<bool>(
        context: context,
        condition: conditionScreen,
        localBreakpoints: localBreakpoints,
        defaultValue: visibleValue,
      );
    }

    return visibleValue;
  }
}

const _defaultConditionScreenVisibility = ConditionScreen<bool>(
  mobile: true,
  tablet: false,
  desktop: false,
);
